@@ -5,9 +5,9 @@
 """
 Taiga Python API library
 """
-__version__ = '1.0.0'
-__author__ = 'Nephila'
-__license__ = 'MIT'
-__all__ = ['TaigaAPI']
+__version__ = "1.1.0"
+__author__ = "Nephila"
+__license__ = "MIT"
+__all__ = ["TaigaAPI"]
 
 from .client import TaigaAPI
